Crate shah_macros

Crate shah_macros 

Macros

perms
routes

Attribute Macros

api
enum_int
enum_ini is a two way conversion enum <-> u16 default start is 0 and default ty is u8 Example:
legacy
Example:
model

Derive Macros

Belt
Derive macro generating an impl of the trait Belt. You can use #[belt(next)], #[belt(past)] and #[belt(buckle)] to set custom fields for these methods.
Buckle
Command
Example:
Duck
Entity
Derive macro generating an impl of the trait Entity.
EnumCode
Example:
Origin
Pond
ShahSchema